//////////////////////////////////////////////////////////////////////////
// Copyright 2001-2011 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

package com.aspose.words.demos;

import com.aspose.words.*;

import java.io.File;

/**
 * Launches the demo-classes sequentially in batch mode using a simple main() method.
 */
public class DemoBatch
{
	public static void main(String[] args) throws Exception
	{
		// Initialize demos.
		Demo.initDemo();

        System.out.println("Initializing paths");
		boolean licensedLoaded = loadLicence();

        if(licensedLoaded)
             System.out.println("License file loaded successfully");
        else
             System.out.println("Note: If these demos are run without an license loaded, an evaluation watermark is " +
                     "injected into the document and content is truncated at a certain point.");

		// Launch all demos sequentially
		Demo demo = new AlternatingRowsDemo();
		generateDemoFile(demo);

		demo = new BarCodeDemo();
		generateDemoFile(demo);

		demo = new DinnerInvitationDemo();
		generateDemoFile(demo);

		demo = new DocumentBuilderDemo();
		generateDemoFile(demo);

		demo = new EmployeesReportDemo();
		generateDemoFile(demo);

		demo = new MailingLabelsDemo();
		generateDemoFile(demo);

		demo = new ProductCatalogDemo();
		generateDemoFile(demo);

		demo = new SalesInvoiceDemo();
		generateDemoFile(demo);

		demo = new SalesReportDemo();
		generateDemoFile(demo);

		demo = new StampAndWatermarkDemo();
		generateDemoFile(demo);

		Demo.closeResources();
	}

	private static boolean loadLicence() throws Exception
	{
		File licenseFile = new File(Demo.getRootDistributiveDir(), "Aspose.Words.Java.lic");
		if (licenseFile.exists())
		{
			// This shows how to license Aspose.Words.
			// If you don't specify a license, Aspose.Words works in evaluation mode.
			License license = new License();
			license.setLicense(licenseFile.getAbsolutePath());
            return true;
		}

        return false;
	}

	private static void generateDemoFile(Demo demo) throws Exception
	{
		try
		{
			System.out.println("\n\r Executing " + demo.getDemoName() +
							   " using template document " + demo.getPathToTemplateDoc());

			Document doc = demo.execute();

		    HtmlSaveOptions htmlOptions = new HtmlSaveOptions();
			htmlOptions.setExportHeadersFootersMode(ExportHeadersFootersMode.NONE);
			// This option improves how tables are displayed when exporting to EPUB format.
            htmlOptions.setTableWidthOutputMode(HtmlElementSizeOutputMode.NONE);
			htmlOptions.setExportXhtmlTransitional(true);

			System.out.println("\tGenerating document in DOC (Microsoft Word 97-2003 Document Format): " + demo.getPathToGeneratedDoc());
			doc.save(demo.getPathToGeneratedDoc());

			System.out.println("\tGenerating document in DOCX (Microsoft Word 2007 Office Open XML Format): " + demo.getPathToGeneratedDocx());
			doc.save(demo.getPathToGeneratedDocx());

            System.out.println("\tGenerating document in PDF (Adobe Portable Document Format): " + demo.getPathToGeneratedPdf());
			doc.save(demo.getPathToGeneratedPdf());

            System.out.println("\tGenerating document in HTML/XHTML (XHTML 1.0 Transitional Format): " + demo.getPathToGeneratedHtml());
			doc.save(demo.getPathToGeneratedHtml(), htmlOptions);

			System.out.println("\tGenerating document in RTF (Rich Text Format 1.9 Format): " + demo.getPathToGeneratedRtf());
			doc.save(demo.getPathToGeneratedRtf());

			System.out.println("\tGenerating document in XPS (Open XML Paper Specification Format): " + demo.getPathToGeneratedXps());
			doc.save(demo.getPathToGeneratedXps());

			System.out.println("\tGenerating document in ODT (OpenDocument Text Format): " + demo.getPathToGeneratedOdt());
			doc.save(demo.getPathToGeneratedOdt());

			htmlOptions.setSaveFormat(SaveFormat.MHTML);
		    System.out.println("\tGenerating document in MHTML (Single File Web Page Format): " + demo.getPathToGeneratedMhtml());
			doc.save(demo.getPathToGeneratedMhtml(), htmlOptions);

			htmlOptions.setSaveFormat(SaveFormat.EPUB);
			System.out.println("\tGenerating document in EPUB (IDPF EPUB Document format): " + demo.getPathToGeneratedEpub());
			doc.save(demo.getPathToGeneratedEpub(), htmlOptions);

			System.out.println("\tGenerating document in TXT (Plain Text Format): " + demo.getPathToGeneratedTxt());
			doc.save(demo.getPathToGeneratedTxt());

			System.out.println("\tGenerating document in XML (Microsoft Word 2003 WordprocessingML Format): " + demo.getPathToGeneratedWml());
			doc.save(demo.getPathToGeneratedWml(), new WordML2003SaveOptions());

			System.out.println("\tGenerating document in XML (FlatOPC OOXML Document Format): " + demo.getPathToGeneratedFopc());
			doc.save(demo.getPathToGeneratedFopc(), new OoxmlSaveOptions(SaveFormat.FLAT_OPC));

			System.out.println("\tGenerating document in SWF (Macromedia Flash File Format): " + demo.getPathToGeneratedSwf());
			doc.save(demo.getPathToGeneratedSwf());
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}
	}
}
