//////////////////////////////////////////////////////////////////////////
// Copyright 2001-2011 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.*;

import java.awt.*;
import java.sql.ResultSet;

/**
 * Creates a list of products with alternating table row colors. Shows how to use DocumentBuilder
 * inside mail merge event handler.
 */
public class AlternatingRowsDemo extends Demo
{
	public AlternatingRowsDemo()
	{
		init("AlternatingRowsDemo");
	}

	public Document execute() throws Exception
    {
        // Open the template document
        Document doc = new Document(getPathToTemplateDoc());

        // Attach a callback handler which is called for each merge field.
		// The handler will apply formatting to each row.
        doc.getMailMerge().setFieldMergingCallback(new FieldMergingHandler(doc));

        // Execute mail merge.
        ResultSet suppliers = executeQuery("SELECT TOP 10 * FROM Suppliers");
        doc.getMailMerge().executeWithRegions(new DataTable(suppliers, "Suppliers"));

		return doc;
    }

    /**
     * Called for every merge field encountered in the document.
     * We can either return some data to the mail merge engine or do something
     * else with the document. In this case we choose to modify cell formatting.
     */
	public class FieldMergingHandler implements IFieldMergingCallback
	{

		public FieldMergingHandler(Document doc)
		{
		   mBuilder = new DocumentBuilder(doc);
           mRowIdx = 1;	// There is one header row, don't color it.
		}

		public void fieldMerging(FieldMergingArgs args){
        	// This way we catch the beginning of a new row.
        	if ("CompanyName".equals(args.getFieldName()))
        	{
        	   // Select the color depending on whether the row number is even or odd.
         	   Color rowColor = (mRowIdx % 2 != 0) ? new Color(242, 242, 242) : new Color(213, 227, 235);
         	   // There is no way to set cell properties for the whole row at the moment,
         	   // so we iterate over all cells in the row.
         	   for (int colIdx = 0; colIdx < 4; colIdx++)
         	   {
          	      mBuilder.moveToCell(0, mRowIdx, colIdx, 0);
          	      mBuilder.getCellFormat().getShading().setBackgroundPatternColor(rowColor);
          	      mBuilder.getCellFormat().getBorders().getTop().setColor(Color.WHITE);
          	  }
          	  // This is somewhat a hack because right now document builder points to a merge field
          	  // and Aspose.Words will replace the field with data leaving document builder cursor dangling.
          	  mBuilder.moveToDocumentStart();
          	  mRowIdx++;
        	}
		}

		public void imageFieldMerging(ImageFieldMergingArgs args){
        	// Do Nothing
		}

		private DocumentBuilder mBuilder;
		private int mRowIdx;
    }
}
