//////////////////////////////////////////////////////////////////////////
// Copyright 2001-2011 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.DataTable;
import com.aspose.words.Document;
import java.sql.ResultSet;

/**
 * Prints company names and addresses on mailing labels. Shows how to use NEXT field.
 */
public class MailingLabelsDemo extends Demo
{
	public MailingLabelsDemo()
	{
		init("MailingLabelsDemo");
	}

    public Document execute() throws Exception
    {
        // Open the template document
		Document doc = new Document(getPathToTemplateDoc());

        // *** Use of NEXT field
        //
        // Note that each mailing label in the document has NEXT field which causes
        // Aspose.Words mail merge engine to retrieve the next record from the data source.
        // When Aspose.Words reaches the end of the document, it repeats the whole document
        // exactly as it does during normal mail merge, thus creating another sheet of labels.
        //
        // Note that NEXT fields are not visible in MS Word unless display of field codes is turned on.
        // To switch between viewing field codes or field results, press Alt+F9 in MS Word.

        // Mail merge customer details from the table to the document.
        ResultSet customers = executeQuery("SELECT TOP 50 * FROM Customers ORDER BY Country, CompanyName;");
        doc.getMailMerge().execute(new DataTable(customers));

        // This is useful if you want to delete any merge fields that might be left at the end of the document.
        doc.getMailMerge().deleteFields();

        // Mail merge will create another sheet of labels on a new section. If the labels were plain text then this
        // would not be visible, but since they are in tables they will leave an empty table on the next page. We remove
        // the content from this empty second section.
        if(doc.getSections().getCount() > 1)
           doc.getLastSection().remove();

		return doc;
    }
}
