//////////////////////////////////////////////////////////////////////////
// Copyright 2001-2011 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.demos;

import com.aspose.words.DataRelation;
import com.aspose.words.DataSet;
import com.aspose.words.DataTable;
import com.aspose.words.Document;
import com.aspose.words.MailMergeCleanupOptions;


/**
 * Creates an invoice with order header, details and summary. Shows how to mail merge hierarchical data from
 * multiple tables, format date and numeric fields and use nested merge regions to grow portions of the document.
 */
public class SalesInvoiceDemo extends Demo
{
	public SalesInvoiceDemo()
	{
		init("SalesInvoiceDemo");
	}

    public Document execute() throws Exception
    {
        //Open the template document
		Document doc = new Document(getPathToTemplateDoc());

        // *** Mail Merge Regions
        //
        // This document uses mail merge regions and nested merge regions. For more information please
        // see the documentation under Mail Merge.

        // *** Parent-Child Data on the Report
        //
        // Note that documents such as invoice might contain data with master-child relationships,
        // for example Order and OrderDetails. The easiest and most natural way to build such a report
        // is to use nested merge regions. These can be easily set up from a variety of data sources and
        // merged in one line of code.
		//
        // This demo is designed to produce multiple invoices each with content from a data source with multiple
        // parent-child relationships. Each invoice is generated on a different page.

        // *** Date and Number Formatting in Merge Fields
        //
        // You can either format your data in the query or specify formatting flags in the merge fields
        // in the document.
        //
        // Merge fields with date or number formatting flags look like this:
        // MERGEFIELD  OrderDate \@ "dd-MMM-yyyy"
        // MERGEFIELD  UnitPrice \# "$#,##0.00"
        //
        // You can switch display of field codes on/off in MS Word using Alt+F9 to see which
        // fields in this demo use formatting flags.

		// Empty paragraphs can appear between some tables within regions. This setting removes these paragraphs automatically during mail merge.
        doc.getMailMerge().setCleanupOptions(MailMergeCleanupOptions.REMOVE_UNUSED_REGIONS);

        // Perform a single mail merge operation which populates the document with data from the data source.
        doc.getMailMerge().executeWithRegions(getOrdersData());

		return doc;
	}

	 private DataSet getOrdersData() throws Exception
    {
	    // Note that mail merging using DataSet or DataTable classes is like working with disconnected data. All data needed for the mail merge
		// operation must be loaded into memory and must be scrollable. Either the ResultSets objects must be scrollable and open
		// for the duration of mail merge or the data can be loaded in a CachedRowSet.
        DataSet dataSet = new DataSet();

		// Add the data from the database into appropriate tables.  The names of the table are required to match to the names in
		// regions in template document.
        DataTable orders = new DataTable(executeQuery("SELECT TOP 3 * FROM AsposeWordOrders"), "Orders");
        dataSet.getTables().add(orders);

		DataTable orderDetails = new DataTable(executeQuery("SELECT * FROM AsposeWordOrderDetails"), "OrderDetails");
		dataSet.getTables().add(orderDetails);

		DataTable orderTotals = new DataTable(executeQuery("SELECT * FROM AsposeWordOrderTotals"), "OrderTotals");
		dataSet.getTables().add(orderTotals);

		// In order for nested mail merge to work, the mail merge engine must know the relation between parent and child tables.
		// Add a DataRelation to specify relations between these tables.
		dataSet.getRelations().add(new DataRelation(
				"OrderToOrderDetails",
				"Orders",
				"OrderDetails",
				new String[]{"OrderID"},
				new String[]{"OrderID"}));

		dataSet.getRelations().add(new DataRelation(
				"OrderToOrderTotals",
				"Orders",
				"OrderTotals",
				new String[]{"OrderID"},
				new String[]{"OrderID"}));

        return dataSet;
    }
}
